<template>
  <div class="notice">
    <el-dialog
        v-model="dialogVisible"
        :title="title"
        width="550px"
        :before-close="handleClose"
    >
      <el-form :model="state.form" size="default" ref="suppleRef" :rules="state.formRules" label-width="110px" >
        <el-form-item label="所属机构:"  prop="agencyId">
          <el-input v-if="isAgency" v-model="state.agencyName" disabled></el-input>
          <el-select v-model="state.form.agencyName"  v-else style="width: 100%" @change="selectValue" :disabled="isReview" v-loadMore="loadMore" class="m-2" placeholder="请选择机构" popper-class="more_select_dropdown"   >
            <el-option
                v-for="item in state.agencyList"
                :key="item.id"
                :label="item.name"
                :value="item.name"
            />
          </el-select>
        </el-form-item>
        <el-form-item label="项目名称:" prop="name">
          <el-input v-model.trim="state.form.name" placeholder="请输入项目名称" :disabled="isReview"></el-input>
        </el-form-item>
        <el-form-item label="项目时间:" prop="filingDate">
          <el-date-picker
              :disabled="isReview"
              style="width: 100%"
              v-model="state.form.filingDate"
              type="date"
              value-format="YYYY-MM-DD"
              placeholder="请选择项目时间"
              size="default"
          />
        </el-form-item>
        <el-form-item label="报告撰写人:" prop="writer">
          <el-input v-model.trim="state.form.writer" placeholder="请输入报告撰写人" :disabled="isReview"></el-input>
        </el-form-item>
        <el-form-item label="报告审批人:" prop="reviewer">
          <el-input v-model.trim="state.form.reviewer" placeholder="请输入报告审批人" :disabled="isReview"></el-input>
        </el-form-item>
        <el-form-item label="报告扫描件:" prop="files">
          <el-upload
              style="width: 100%;"
              :disabled="isReview"
              accept="image/*,.pdf,.doc,.docx,.xlsx,.xls"
              :action="state.uploadUrl"
              :headers="state.header"
              method="post"
              :on-success="(res, uploadFile)=>handleAvatarSuccess(res, uploadFile)"
              :on-exceed="showTip"
              v-model:file-list="state.fileList"
              :on-remove="handleRemove"
              :data="state.uploadData"
              :on-preview="handlePreview"
              :limit='15'
              :before-upload="picSize"
          >
            <el-button type="primary">报告上传</el-button>
            <template #tip>
              <div class="el-upload__tip" v-if="!isReview">上传文件尺寸小于15M，最多可上传15份，多张图片建议合并为PDF文件规范上传。</div>
            </template>
          </el-upload>
        </el-form-item>
      </el-form>
      <template #footer v-if="!isReview">
        <span class="dialog-footer">
            <el-button @click="handleClose" size="default">取 消</el-button>
            <el-button type="primary"  @click="onSubmit" size="default" v-preReClick>确 认</el-button>
        </span>
      </template>
    </el-dialog>
  </div>
</template>
<script setup>
import {reactive, ref, toRefs} from 'vue'
import {ElMessage, ElMessageBox} from "element-plus";
import {addLaw, editLaw, getLawDetail} from "@/api/backManage/law";
import axios from "axios";
import {getToken} from "@/utils/auth";
import {delAccessoryFile} from "@/api/projectManage/project";
import {addSupplement, editSupplement, getSupplementDetail} from "@/api/backManage/supplement";
import Cookies from "js-cookie";
import {delPic} from "@/api/login";
import {getInsitutionList} from "@/api/backManage/insitution";
import {get} from "@vueuse/core";

const emit = defineEmits(["getList"]);
const dialogVisible = ref(false);
const title = ref("");
const suppleRef = ref();
const isReview = ref(false);
const law = ref(1)
const state = reactive({
  form: {
    agencyId: '',
    id: '',
    name: '',
    filingDate: '',
    writer: '',
    reviewer:'',
    files: []

  },
  formRules:{
    agencyId:[{ required: true, message: '请选择所属机构', trigger: 'blur' }],
    name: [{ required: true, message: '请填写项目名称', trigger: 'blur' }],
    writer: [{ required: true, message: '请填写报告撰写人', trigger: 'blur' }],
    reviewer: [{ required: true, message: '请填写报告审批人', trigger: 'blur' }],
    files: [{ required: true, message: '请上传报告扫描件', trigger: 'blur' }],
    filingDate:[{ required: true, message: '请选择项目时间', trigger: 'blur' }],
  },
  uploadUrl: import.meta.env.VITE_APP_BASE_API + '/system/common/uploadFile',
  header: {
    Authorization: getToken()
  },
  fileList: [],
  agencyName:'',
  agencyId: '',
  agencyList: [],
  pageNum: 1,
  pageSize: 10,
  agency: {

  }
})

const isAgency = ref(false);
const getUserInfoAgency = () => {
  const userInfo = JSON.parse(Cookies.get('userInfo'))
  if (userInfo.identity === 1) {
    state.agencyName = userInfo.agentName;
    state.form.agencyId = userInfo.agentId;
    isAgency.value = true;
  } else {
    getAgency('open')
  }
}
const openDialog = async (type, value) => {
  await getUserInfoAgency();
  isReview.value = false;
  title.value = type === 'add' ? '新增' : type ==='edit' ? '编辑' : '查看' ;
  if(type === 'edit' || type === 'review') {
    const param = {
      projectId: value.id
    }
    const res = await getSupplementDetail(param);
    if(res.code === 200){
      state.form = res.data
      state.form.filingDate = res.data.filingDate.substring(0,10)
      state.fileList = res.data.files.map(item => {
        return {
          ...item,
          name: item.originName,
        }
      })
      state.agency.id = res.data.agencyId;
      state.agency.name = res.data.agencyName
      console.log('state.fileList',state.form)
    }else{
      ElMessage.warning(res.message)
    }

  }
  if(type === 'add'|| type ==='edit'){
    isReview.value = false;
  }
  if(type === 'review') {
    isReview.value = true;
  }
  dialogVisible.value = true;
}

const onSubmit = async () => {
  const valid = await suppleRef.value.validate();
  if(valid){
    if(title.value === '新增'){
      state.form.filingDate = state.form.filingDate.concat(" 00:00:00")
      state.form.filingDate = state.form.filingDate.substring(0,19)

      state.form.files = state.fileList.map(i=>{
        return {
          originName: i.response.data.originName,
          fileName: i.response.data.filename,
          path: i.response.data.path,
        }
      })
      console.log('dd',state.form)
      const {id, ...data} = JSON.parse(JSON.stringify(state.form))
      // data.agencyId = state.agencyId
      const res = await addSupplement(data)
      if(res.code === 200){
        ElMessage({
          type: 'success',
          message: '新增成功'
        });
      }else{
        ElMessage.warning(res.message)
      }
      emit("getList")
      reset();
      suppleRef.value.clearValidate();
      dialogVisible.value = false;
    }else if(title.value === '编辑') {
      state.form.filingDate = state.form.filingDate.concat(" 00:00:00")
      state.form.filingDate = state.form.filingDate.substring(0,19)
      console.log('dd',state.form)
      state.form.files = state.fileList.map(i=>{
        return {
          originName: i.response ? i.response.data.originName : i.originName,
          fileName: i.response ? i.response.data.filename : i.fileName ,
          path: i.response ? i.response.data.path : i.path ,
        }
      })
      const {...data} = JSON.parse(JSON.stringify(state.form))
      // data.agencyId = state.agencyId
      const res = await editSupplement(data)
      if(res.code === 200){
        ElMessage({
          type: 'success',
          message: '编辑成功'
        });
      }else{
        ElMessage.warning(res.message)
      }
      emit("getList")
      reset();
      suppleRef.value.clearValidate();
      dialogVisible.value = false;
    }

  }
}

const handleClose = () => {
  reset();
  suppleRef.value.clearValidate();

  dialogVisible.value = false;
}
const reset = () => {
  state.form = {
    agencyId: '',
    id: '',
    name: '',
    filingDate: '',
    writer: '',
    reviewer:'',
    files: []
  }
  state.fileList = [];
}
const handleAvatarSuccess = (res,uploadFile) => {
  if(res.code === 200){
    state.form.files = state.fileList;
    ElMessage({
      type: 'success',
      message: '文件上传成功'
    })
  }else {
    state.fileList.splice(state.fileList.indexOf(uploadFile),1)
    ElMessage({
      type: 'warning',
      message: res.message
    })
  }
}
// 上传
const showTip =()=>{
  ElMessage({
    type: 'warning',
    message: '超出文件上传数量'
  });
}

const picSize = async (rawFile) => {
  console.log("111",rawFile.name.length)
  if(rawFile.name.length >100){
    ElMessage({
      type: 'warning',
      message: '文件名不能超过100字'
    });
    return false
  }
  if(rawFile.size / 1024 / 1024 > 15){
    ElMessage({
      type: 'warning',
      message: '文件大小不能超过15M'
    });
    return false
  }
};
const handleRemove = async (file, uploadFiles) => {
  if (file && file.status === 'success') {
  ElMessageBox.confirm(
      '确定删除该附件？',
      '提示',
      {
        confirmButtonText: '确定',
        cancelButtonText: '取消',
        type: 'warning',
      })
      .then(async () => {
        let path = "";
        if (file.path) {
          path = file.path
        } else {
          path = file.response.data.path
        }
        const res = await delPic({path: path})
        if (res.code == 200) {
          ElMessage({
            type: 'success',
            message: '文件已删除'
          })
          state.form.files = state.fileList;
        } else {
          ElMessage({
            type: 'warning',
            message: res.message
          })
        }
      })
      .catch(() => {
      })
  }
}
const handlePreview = (file) => {
  let path = "";
  if(file.path){
    path = file.path
  }else {
    path = file.response.data.path

  }
  const url = import.meta.env.VITE_APP_BASE_API + '/' + path
  axios.get( url,{
        headers:
            {
              'Content-Type': 'application/json',
              'Authorization':getToken(),
            },
        responseType: 'blob'
      }
  ).then(res=>{
    if (res) {
      const link = document.createElement('a')
      let blob = new Blob([res.data],{type: res.data.type})
      link.style.display = "none";
      link.href = URL.createObjectURL(blob); // 创建URL
      link.setAttribute("download", file.name);
      document.body.appendChild(link);
      link.click();
      document.body.removeChild(link);
    } else {
      this.$message.error('获取文件失败')
    }
  })
}

const finshed = ref(false)
const getAgency = async (type) => {
  if (type === 'open' && state.pageNum !== 1) {

  } else {
    const queryParams = {
      pageNum: state.pageNum,
      pageSize: state.pageSize,
    }
    const res = await getInsitutionList(queryParams)
    if(res.code == 200){
      if(res.data.pageNum === state.pageNum){
        finshed.value = false;
        if(state.pageNum == 1){
          state.agencyList = res.data.list
        }else {
          state.agencyList =state.agencyList .concat(res.data.list)
        }
      }else {
        finshed.value = true;
      }
    }else{
      ElMessage.warning(res.message)
    }
  }
}
const selectValue = (val) => {
  state.agencyList.forEach(item => {
    if(item.name === val){
      state.form.agencyId = item.id
    }
  })

}
//触底函数
const loadMore = () => {
  console.log(' 触底了');
  // 防抖处理
  setTimeout(() => {
    if (finshed.value) return //值为true，则代表没有数据了
    state.pageNum += 1
    getAgency('')
  }, 500)
}

defineExpose({
  openDialog
});

</script>

<style scoped lang="scss">
.notice{
  :deep(.el-form .el-form-item__label) {
    font-size: 15px;
  }
  .file {
    display: flex;
    flex-direction: column;
    align-items: flex-start;
  }
}
.reviewTable {
  :deep(table){
    border: 1px solid #ccc;
    text-align: center;
  }
  :deep(table td){
    border: 1px solid #ccc;
    text-align: center;
    padding: 0 5px;
  }
  :deep(table th){
    border: 1px solid #ccc;
  }
}
</style>
